@@ -9,7 +9,7 @@
  *
  * ```js
  * // encoding step
- * const encoder = new encoding.createEncoder()
+ * const encoder = encoding.createEncoder()
  * encoding.writeVarUint(encoder, 256)
  * encoding.writeVarString(encoder, 'Hello world!')
  * const buf = encoding.toUint8Array(encoder)
@@ -17,7 +17,7 @@
  *
  * ```js
  * // decoding step
- * const decoder = new decoding.createDecoder(buf)
+ * const decoder = decoding.createDecoder(buf)
  * decoding.readVarUint(decoder) // => 256
  * decoding.readVarString(decoder) // => 'Hello world!'
  * decoding.hasContent(decoder) // => false - all data is read
@@ -31,6 +31,7 @@ import * as math from './math.js'
 import * as number from './number.js'
 import * as binary from './binary.js'
 import * as string from './string.js'
+import * as array from './array.js'
 
 /**
  * A BinaryEncoder handles the encoding to an Uint8Array.
@@ -52,6 +53,15 @@ export class Encoder {
  */
 export const createEncoder = () => new Encoder()
 
+/**
+ * @param {function(Encoder):void} f
+ */
+export const encode = (f) => {
+  const encoder = createEncoder()
+  f(encoder)
+  return toUint8Array(encoder)
+}
+
 /**
  * The current length of the encoded data.
  *
@@ -67,6 +77,15 @@ export const length = encoder => {
   return len
 }
 
+/**
+ * Check whether encoder is empty.
+ *
+ * @function
+ * @param {Encoder} encoder
+ * @return {boolean}
+ */
+export const hasContent = encoder => encoder.cpos > 0 || encoder.bufs.length > 0
+
 /**
  * Transform to Uint8Array.
  *
@@ -288,7 +307,7 @@ const _maxStrBSize = _strBuffer.length / 3
 export const _writeVarStringNative = (encoder, str) => {
   if (str.length < _maxStrBSize) {
     // We can encode the string into the existing buffer
-    /* istanbul ignore else */
+    /* c8 ignore next */
     const written = string.utf8TextEncoder.encodeInto(str, _strBuffer).written || 0
     writeVarUint(encoder, written)
     for (let i = 0; i < written; i++) {
@@ -322,8 +341,8 @@ export const _writeVarStringPolyfill = (encoder, str) => {
  * @param {Encoder} encoder
  * @param {String} str The string that is to be encoded.
  */
-/* istanbul ignore next */
-export const writeVarString = (string.utf8TextEncoder && string.utf8TextEncoder.encodeInto) ? _writeVarStringNative : _writeVarStringPolyfill
+/* c8 ignore next */
+export const writeVarString = (string.utf8TextEncoder && /** @type {any} */ (string.utf8TextEncoder).encodeInto) ? _writeVarStringNative : _writeVarStringPolyfill
 
 /**
  * Write the content of another Encoder.
@@ -504,7 +523,7 @@ export const writeAny = (encoder, data) => {
       if (data === null) {
         // TYPE 126: null
         write(encoder, 126)
-      } else if (data instanceof Array) {
+      } else if (array.isArray(data)) {
         // TYPE 117: Array
         write(encoder, 117)
         writeVarUint(encoder, data.length)
@@ -660,7 +679,6 @@ export class RleIntDiffEncoder extends Encoder {
  * @param {UintOptRleEncoder} encoder
  */
 const flushUintOptRleEncoder = encoder => {
-  /* istanbul ignore else */
   if (encoder.count > 0) {
     // flush counter, unless this is the first value (count = 0)
     // case 1: just a single value. set sign to positive
