@@ -1,5 +1,5 @@
 
-import * as log from './logging.js'
+import * as log from 'lib0/logging'
 
 export const testLogging = () => {
   log.print(log.BLUE, 'blue ')
